#Load the dataset Faramea.txt and give it the name faramea.
faramea <- read.table(file.choose())
attach(faramea)

#To calculate a linear regression model:
Count.model1 <- lm(Faramea.occidentalis ~ Precipitation, data=faramea, na.action=na.exclude)
summary(Count.model1)
fitted(Count.model1)
predict(Count.model1, interval="confidence")
residuals(Count.model1)
shapiro.test(residuals(Count.model1))
ks.test(residuals(Count.model1), pnorm)
anova(Count.model1,test="F")
Count.model2 <- lm(Faramea.occidentalis ~ Age.cat, data=faramea, na.action=na.omit)
levene.test(residuals(Count.model2), na.omit(faramea)$Age.cat)

#To plot a linear regression model:
plot(Count.model1)
termplot(Count.model1, se=T, partial.resid=T, rug=T,terms="Precipitation")
library(effects)
as.data.frame(effect('Precipitation',Count.model1))
plot(effect("Precipitation", Count.model1))

#To check for the spatial distribution of residuals:
surface.1 <- residualssurface(Count.model1, na.omit(faramea),"UTM.EW", "UTM.NS", gam=F, npol=1, plotit=T, bubble=F, fill=F)
surface.2 <- residualssurface(Count.model1, na.omit(faramea),"UTM.EW", "UTM.NS", gam=F, npol=2, plotit=T, bubble=F, fill=F)
surface.gam <- residualssurface(Count.model1, na.omit(faramea), "UTM.EW", "UTM.NS", gam=T, npol=2, plotit=T, bubble=F, fill=T)
summary(surface.1)
anova(surface.1)
correlogram(surface.1, nint=10)
summary(surface.gam)

#To calculate a generalized linear regression model (GLM):
Count.model3 <- glm(formula = Faramea.occidentalis ~ Precipitation, family = poisson(),data=faramea, na.action=na.exclude)
summary(Count.model3)
anova(Count.model3,test="F")
predict(Count.model3, type="response", se.fit=T)
Count.model4 <- glm(formula = Faramea.occidentalis ~ Precipitation, family = quasipoisson(), data=faramea, na.action=na.exclude)
summary(Count.model4)
anova(Count.model4,test="F")
Count.model5 <- glm.nb(Faramea.occidentalis ~ Precipitation, maxit = 5000, init.theta = 1, data=faramea, na.action=na.exclude)
summary(Count.model5)
anova(Count.model5,test="F")

#To calculate a generalized additive regression model (GAM):
Count.model6 <- gam(Faramea.occidentalis ~ s(Precipitation),family=poisson(), data = na.omit(faramea))
summary(Count.model6)
predict(Count.model6, type="response", se.fit=T)

#To calculate a multiple regression model:
Count.model7 <- glm.nb(Faramea.occidentalis ~ Precipitation + I(Precipitation^2), maxit = 5000, init.theta = 1, data=faramea, na.action=na.exclude)
summary(Count.model7)
anova(Count.model7, test="F")
Anova(Count.model7, type="II", test="Wald")
vif(lm(Faramea.occidentalis ~ Precipitation + I(Precipitation^2), data=faramea, na.action=na.exclude))
