#Calculating a principal component analysis (PCA)
Ordination.model1 <- rda(dune)
summary(Ordination.model1, scaling=1)
plot1 <- ordiplot(Ordination.model1, scaling=1, type="text")
plot2 <- ordiplot(Ordination.model1, scaling=2, type="text")

#Calculating the variance of each species of the species matrix
inertcomp(Ordination.model1, display="species",statistic="explained", proportional=F)

#Calculating the proportion of variance explained for an ordination graph
goodness(Ordination.model1, display="sites", choices=c(1:2),statistic="explained")

#Adding a vector and perpendicular lines for a particular species to an ordination plot
ordivector(plot1,"Agrsto",lty=2)

#Calculating correlations among vectors:
cor.test(dune[,"Alogen"],dune[,"Agrsto"])

#Calculating the number of ecologically meaningful principal components:
PCAsignificance(Ordination.model1,axes=30)
screeplot.cca(Ordination.model1,bstick=T)

#Drawing an equilibrium circle
plot1 <- ordiplot(Ordination.model1, scaling=1, type="text")
ordiequilibriumcircle(Ordination.model1,plot1)

#Calculating a PCA on a transformed matrix
Community.1 <- disttransform(dune, method="hellinger")
Ordination.model2 <- rda(Community.1)
summary(Ordination.model2, scaling=1)
plot3 <- ordiplot(Ordination.model2, scaling=1, type="text")

#Calculating a principal coordinates analysis (PCoA)
distmatrix <- vegdist(dune,method="bray")
Ordination.model3 <- cmdscale(distmatrix, k=nrow(dune)-1,eig=T, add=F)
plot4 <- ordiplot(Ordination.model3, type="text")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
Ordination.model3 <- add.spec.scores( Ordination.model3, dune,method="pcoa.scores", Rscale=F, scaling=1, multi=0.1)
plot4 <- ordiplot(Ordination.model3, type="text")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)

#Calculating a non-metric multidimensional scaling (NMS)
distmatrix <- vegdist(dune, method="bray")
initNMS <- NMSrandom(distmatrix, perm=100, k=2)
Ordination.model4 <- postMDS(initNMS, distmatrix)
Ordination.model4 <- add.spec.scores( Ordination.model4, dune, method="wa.scores")
Ordination.model4
plot5 <- ordiplot(Ordination.model4, type="text")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)

#Calculating a correspondence analysis (CA or WA)
Ordination.model5 <- cca(dune)
summary(Ordination.model5, scaling=1)
plot6 <- ordiplot(Ordination.model5, type="text", scaling=1)

#Calculating a redundancy analysis (RDA)
Ordination.model6 <- rda(dune ~ Management, dune.env)
summary(Ordination.model6, scaling=1)
permutest.cca(Ordination.model6, permutations=1000)
plot7 <- ordiplot(Ordination.model6, type="text", scaling=1)

#Calculating a canonical correspondence analysis (CCA)
Ordination.model7 <- cca(dune ~ Management, dune.env)
summary(Ordination.model7, scaling=2)
permutest.cca(Ordination.model7, permutations=1000)
plot8 <- ordiplot(Ordination.model7, type="text", scaling=1)

#Calculating distance-based redundancy analysis (db-RDA)
Ordination.model8 <- capscale(dune ~ Management, dune.env)
summary(Ordination.model8, scaling=1)
permutest.cca(Ordination.model8, permutations=1000)
plot9 <- ordiplot(Ordination.model8, type="text", scaling=1)

#Calculating the correlation between distance in an ordination graph and total distance
distmatrix <- vegdist(dune,method="bray")
Ordination.model3 <- cmdscale(distmatrix, k=nrow(dune)-1,eig=T, add=F)
plot4 <- ordiplot(Ordination.model3, type="text")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
distdisplayed(dune, plot4, distx="bray")

#Plotting clustering results onto an ordination graph
distmatrix <- vegdist(dune, method="bray")
Ordination.model3 <- cmdscale(distmatrix, k=nrow(dune)-1,eig=T, add=F)
plot4 <- ordiplot(Ordination.model3, type="text")
cluster <- hclust(distmatrix, method="single")
ordicluster(plot4, cluster,col="green")

#Plotting quantitative environmental variables onto an ordination graph
distmatrix <- vegdist(dune, method="bray")
Ordination.model3 <- cmdscale(distmatrix, k=nrow(dune)-1,eig=T, add=F)
plot4 <- ordiplot(Ordination.model3, type="text")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
attach(dune.env)
fitted <- envfit(plot4, data.frame(A1), permutations=100)
fitted
plot(fitted)
ordibubble(plot4, A1)
ordisurf(plot4, A1)

#Plotting categorical environmental variables onto an ordination graph
distmatrix <- vegdist(dune, method="bray")
Ordination.model3 <- cmdscale(distmatrix, k=nrow(dune)-1,eig=T, add=F)
plot4 <- ordiplot(Ordination.model3, type="n")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
ordisymbol(plot4, dune.env, "Management", legend=T)
# Click in the figure where the legend should be placed
attach(dune.env)
fitted2 <- envfit(plot4, data.frame(Management), permutations=100)
fitted2
plot(fitted2)
plot4 <- ordiplot(Ordination.model3, type="p")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
ordihull(plot4, Management)
plot4 <- ordiplot(Ordination.model3, type="p")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
ordispider(plot4, Management)
plot4 <- ordiplot(Ordination.model3, type="p")
abline(h = 0, lty = 3)
abline(v = 0, lty = 3)
ordiellipse(plot4, Management)
